CI: Add tests for onf-make

Since this is a library of makefiles, standard code tests can't be
implemented. Instead, this change introduces modified versions of
build & test jobs for other repos, which are kicked off by pushes
to onf-make, and test those builds with the change to the onf-make
library.

Signed-off-by: Eric Ball <eball@linuxfoundation.org>
Change-Id: I1e40e2a49996c5a04f0d5bc6cba7a0eb603ed8e5
diff --git a/jjb/shell/make-unit.sh b/jjb/shell/make-unit.sh
index 9a69b60..03f98ef 100755
--- a/jjb/shell/make-unit.sh
+++ b/jjb/shell/make-unit.sh
@@ -20,13 +20,13 @@
 # when not running under Jenkins, use current dir as workspace, a blank project
 # name
 WORKSPACE=${WORKSPACE:-.}
-GERRIT_PROJECT=${GERRIT_PROJECT:-}
+TEST_PROJECT="${TEST_PROJECT:-}"
 
 # Fixes to for golang projects to support GOPATH
 # If $DEST_GOPATH is not an empty string:
 # - create GOPATH within WORKSPACE, and destination directory within
 # - set PATH to include $GOPATH/bin and the system go binaries
 # - move project from $WORKSPACE/$GERRIT_PROJECT to new location in $GOPATH
 # - start tests within that directory
 
 DEST_GOPATH=${DEST_GOPATH:-}
@@ -34,10 +34,10 @@
   export GOPATH=${GOPATH:-$WORKSPACE/go}
   mkdir -p "$GOPATH/src/$DEST_GOPATH"
   export PATH=$PATH:/usr/lib/go-1.12/bin:/usr/local/go/bin:$GOPATH/bin
-  test_path="$GOPATH/src/$DEST_GOPATH/$GERRIT_PROJECT"
-  mv "$WORKSPACE/$GERRIT_PROJECT" "$test_path"
+  test_path="$GOPATH/src/$DEST_GOPATH/$TEST_PROJECT"
+  mv "$WORKSPACE/$TEST_PROJECT" "$test_path"
 else
-  test_path="$WORKSPACE/$GERRIT_PROJECT"
+  test_path="$WORKSPACE/$TEST_PROJECT"
 fi
 
 # Use "test" as the default target, can be a space separated list
@@ -20,13 +20,13 @@
 # - create GOPATH within WORKSPACE, and destination directory within
 # - set PATH to include $GOPATH/bin and the system go binaries
-# - move project from $WORKSPACE/$GERRIT_PROJECT to new location in $GOPATH
+# - move project from $WORKSPACE/$TEST_PROJECT to new location in $GOPATH
 # - start tests within that directory
 